@@ -81,13 +81,21 @@ void Vt102Emulation::clearEntireScreen()
 
 void Vt102Emulation::reset()
 {
+  // Save the current codec so we can set it later.
+  // Ideally we would want to use the profile setting
+  const QTextCodec* currentCodec = codec();
+
   resetTokenizer();
   resetModes();
   resetCharset(0);
   _screen[0]->reset();
   resetCharset(1);
   _screen[1]->reset();
-  setCodec(LocaleCodec);
+
+  if (currentCodec)
+    setCodec(currentCodec);
+  else
+    setCodec(LocaleCodec);
  
   bufferedUpdate();
 }
@@ -532,7 +540,7 @@ void Vt102Emulation::processToken(int token, int p, int q)
     case TY_ESC_DE('8'      ) : _currentScreen->helpAlign            (          ); break;
 
 // resize = \e[8;<row>;<col>t
-    case TY_CSI_PS('t',   8) : setImageSize( q /* columns */, p /* lines */ );    break;
+    case TY_CSI_PS('t',   8) : setImageSize( p /*lines */, q /* columns */ );    break;
 
 // change tab text color : \e[28;<color>t  color: 0-16,777,215
     case TY_CSI_PS('t',   28) : emit changeTabTextColorRequest      ( p        );          break;
